<?php

namespace app\admin\model;

use support\Db;
use support\Model;

/**
 * 悦活健康美食订单
 * Class Order
 * @package app\admin\model
 */
class LifeFoodOrder extends Model
{
    /**
     *
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'life_healthy_order';

    public $timestamps = false;

    /**
     * Notes:获取订单列表
     * @param string $keywords
     * @param int $page
     * @param int $limit
     * @return array
     * User: ZQ
     * Date: 2022/10/13
     */
    public static function getOrderList(int $page, int $limit,$keywords)
    {
        $list = static::select(['life_healthy_order.*','merchant_shop.shop_name'])
            ->leftJoin('merchant_shop','shop_id','=','life_healthy_order.order_shop_id')
            ->when($keywords != '', function ($query) use ($keywords){
                $query->where('order_sn', 'like', '%' . $keywords . '%');
            })
            ->with(['user','Detail'])
            ->orderBy('order_create_time','DESC')
            ->forPage($page, $limit)
            ->get()->toArray();

        $count = static::when($keywords != '', function ($query) use ($keywords){
            $query->where('order_sn', 'like', '%' . $keywords . '%');
        })->count();
        return [$list, $count];
    }

    //关联店铺
    public function Shop(){
        return $this->belongsTo(MerchantShop::class,'order_shop_id','shop_id');
    }
    //获取用户信息
   public function User(){
        return $this->belongsTo(User::class,'order_user_id','user_id');
   }
    //获取订单详情
    public function Detail(){
        return $this->hasMany(LifeFoodOrderDetail::class,'detail_order_id','order_id')
            ->leftJoin('life_healthy_food','food_id','=','life_healthy_order_detail.detail_goods_id')
            ->select(['life_healthy_order_detail.*','life_healthy_food.food_name']);
    }
}