<?php

namespace app\admin\model;

use support\Db;
use support\Model;

/**
 * 养老产品订单
 * Class Order
 * @package app\admin\model
 */
class RaiseGoodsOrder extends Model
{
    /**
     *
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'raise_old_order';

    public $timestamps = false;

    /**
     * Notes:获取订单列表
     * @param string $keywords
     * @param int $page
     * @param int $limit
     * @return array
     * User: ZQ
     * Date: 2022/11/1
     */
    public static function getOrderList(int $page, int $limit,$keywords)
    {
        $list = static::select(['raise_old_order.*','raise_old_goods.goods_name'])
            ->leftJoin('raise_old_goods','goods_id','=','raise_old_order.order_goods_id')
            ->when($keywords != '', function ($query) use ($keywords){
                $query->where('order_dno', 'like', '%' . $keywords . '%');
            })
            ->with(['user'])
            ->orderBy('order_create_time','DESC')
            ->forPage($page, $limit)
            ->get()->toArray();

        $count = static::when($keywords != '', function ($query) use ($keywords){
            $query->where('order_sn', 'like', '%' . $keywords . '%');
        })->count();
        return [$list, $count];
    }

    //关联店铺
    public function Shop(){
        return $this->belongsTo(MerchantShop::class,'order_shop_id','shop_id');
    }
    //获取用户信息
   public function User(){
        return $this->belongsTo(User::class,'order_user_id','user_id');
   }
    //获取订单详情
    public function Detail(){
        return $this->hasMany(GoodsOrderDetail::class,'detail_order_id','order_id')
            ->leftJoin('life_market_goods','goods_id','=','life_market_order_detail.detail_goods_id')
            ->select(['life_market_order_detail.*','life_market_goods.goods_name']);
    }
}